@@ -1,4 +1,3 @@
-
 /// Implementation of a Canny Edge Detector and associated types
 pub mod canny;
 /// Image convolutions in 2D
@@ -9,12 +8,15 @@ pub mod filter;
 pub mod kernels;
 /// Sobel operator for edge detection
 pub mod sobel;
+/// Thresholding functions
+pub mod threshold;
 
 pub use canny::*;
 pub use conv::*;
 pub use filter::*;
 pub use kernels::*;
 pub use sobel::*;
+pub use threshold::*;
 
 /// Common error type for image processing algorithms
 #[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash, Debug)]
@@ -26,7 +28,7 @@ pub enum Error {
     /// Invalid dimensions to an algorithm - this includes rows and columns and
     /// relationships between the two
     InvalidDimensions,
-    /// An invalid parameter has been supplied to an algorithm. 
+    /// An invalid parameter has been supplied to an algorithm.
     InvalidParameter,
     /// Numeric error such as an invalid conversion or issues in floating point
     /// math. As `ndarray` and `ndarray-vision` rely on `num_traits` for a lot
